@@ -65,7 +65,7 @@ class DBConfig(BaseModel):
     def dsn_str(self) -> str:
         if self.is_plaintext_dsn:
             return f'"{self.dsn_}"'
-        return f"os.environ[{self.dsn_}]"
+        return f'os.environ["{self.dsn_}"]'
 
 
 PATH_TO_MODULE = "edgedb_orm"
