@@ -136,11 +136,19 @@ def basemodel_to_str(
     default_replace: bool = False,
     fields_to_exclude: T.Set[str] = None,
     force_replace: bool = False,
+    exclude_none: bool = False,
+    exclude_unsets: bool = True,
 ) -> T.Tuple[str, T.Dict[str, T.Any]]:
     # should exclude_none = True?
     # model_d = model.dict(exclude_none=True, exclude=fields_to_exclude)
     # TODO is this right?
-    model_d = model.dict(exclude=fields_to_exclude)
+    if exclude_unsets:
+        unset_keys = {k for k in model.__fields__ if getattr(model, k, None) is UNSET}
+        fields_to_exclude = (
+            fields_to_exclude if fields_to_exclude is not None else set()
+        )
+        fields_to_exclude.update(unset_keys)
+    model_d = model.dict(exclude=fields_to_exclude, exclude_none=exclude_none)
 
     set_links_d = make_set_links_d(
         model=model, model_d=model_d, default_replace=default_replace
@@ -327,8 +335,10 @@ class Node(BaseModel, T.Generic[InsertType, PatchType]):
         )
         # I think default_replace=True is correct here. Your intention is to make sure these links are SET, not updated
         # if your intention is for them to update on upsert, then add ADD to the resolver
+
+        # FOR INSERTING, YOU SHOULD EXCLUDE UNSET
         s, variables = basemodel_to_str(
-            insert, default_replace=True, force_replace=True
+            insert, default_replace=True, force_replace=True, exclude_unsets=True
         )
         insert_str = f"INSERT {cls._model_name} {s}"
         conflict_str = ""
@@ -387,6 +397,9 @@ class Node(BaseModel, T.Generic[InsertType, PatchType]):
         )
         if not inserts:
             return list()
+
+        no_id_given = UNSET in [i.id for i in inserts]
+
         insert_str = creating_strings.insert_str_from_cls(
             insert_cls=inserts[0].__class__,
             node_cls=cls,
@@ -394,6 +407,7 @@ class Node(BaseModel, T.Generic[InsertType, PatchType]):
             upsert_given_conflict_on=upsert_given_conflict_on,
             return_conflicting_model_on=return_conflicting_model_on,
             custom_on_conflict_str=custom_on_conflict_str,
+            include_id=not no_id_given,
         )
         full_insert_str = f"""
 with
@@ -403,7 +417,10 @@ for item in json_array_unpack(raw_data) union ({insert_str}) {given_resolver.to_
         print(f"{full_insert_str=}")
         data: T.List[T.Dict[str, T.Any]] = []
         for insert in inserts:
-            d = insert.dict(exclude_none=True)
+            fields_to_exclude = {
+                k for k in insert.__fields__ if getattr(insert, k) is UNSET
+            }
+            d = insert.dict(exclude_none=True, exclude=fields_to_exclude)
             # TODO for bulk adding, best to exclude
             # d = insert.dict()
             # if the cast says they should be strings and they are not, turn them into json
