@@ -548,7 +548,8 @@ class Resolver(BaseModel, T.Generic[NodeType]):
                 variables=self._get_nested_query_variables(),
                 only_one=only_one,
             )
-        with safe_span(op=f"parse.{self._model_name}", description=f"{len(raw_d)=}"):
+        description = len(raw_d) if not only_one else "only-one"
+        with safe_span(op=f"parse.{self._model_name}", description=f"{description}"):
             if not only_one:
                 return [self.parse_nested_obj(d) for d in raw_d]
             if not raw_d:
